@@ -1,4 +1,4 @@
-from charting import *
+from charting import chart
 from tokens import *
 from time import sleep
 
